==> gluegen2_2.2.4.orig.tar.xz: gluegen-v2.2.4/src/java/com/jogamp/gluegen/TypeInfo.java <==
/*
 * Copyright (c) 2003 Sun Microsystems, Inc. All Rights Reserved.
 * Copyright (c) 2010 JogAmp Community. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * - Redistribution of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * - Redistribution in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 *
 * Neither the name of Sun Microsystems, Inc. or the names of
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * This software is provided "AS IS," without a warranty of any kind. ALL
 * EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES,
 * INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY EXCLUDED. SUN
 * MICROSYSTEMS, INC. ("SUN") AND ITS LICENSORS SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WILL SUN OR
 * ITS LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR
 * DIRECT, INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE
 * DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY,
 * ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF
 * SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 *
 * You acknowledge that this software is not designed or intended for use
 * in the design, construction, operation or maintenance of any nuclear
 * facility.
 *
 * Sun gratefully acknowledges that this software was originally authored
 * and developed by Kenneth Bradley Russell and Christopher John Kline.
 */

package com.jogamp.gluegen;

/** Utility class for handling Opaque directives for JavaEmitter. */

public class TypeInfo {
  private final String   name;
  private final int      pointerDepth;
  private final JavaType javaType;
  private TypeInfo next;

  public TypeInfo(final String name, final int pointerDepth, final JavaType javaType) {
    this.name = name;
    this.pointerDepth = pointerDepth;
    this.javaType = javaType;
  }

  public String   name()                 { return name; }
  public int      pointerDepth()         { return pointerDepth; }
  public JavaType javaType()             { return javaType; }
  public void     setNext(final TypeInfo info) { this.next = info; }
  public TypeInfo next()                 { return next; }

  @Override
  public String toString() {
    final StringBuilder buf = new StringBuilder("TypeInfo: ");
    buf.append(name);
    buf.append(" pointerDepth ");
    buf.append(pointerDepth);
    buf.append(" JavaType " + javaType);
    return buf.toString();
  }
}

==> gluegen2_2.6.0+dfsg.orig.tar.xz: gluegen-v2.6.0/src/java/com/jogamp/gluegen/TypeInfo.java <==
/*
 * Copyright (c) 2003 Sun Microsystems, Inc. All Rights Reserved.
 * Copyright (c) 2010 JogAmp Community. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * - Redistribution of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * - Redistribution in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 *
 * Neither the name of Sun Microsystems, Inc. or the names of
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * This software is provided "AS IS," without a warranty of any kind. ALL
 * EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES,
 * INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY EXCLUDED. SUN
 * MICROSYSTEMS, INC. ("SUN") AND ITS LICENSORS SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WILL SUN OR
 * ITS LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR
 * DIRECT, INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE
 * DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY,
 * ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF
 * SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 *
 * You acknowledge that this software is not designed or intended for use
 * in the design, construction, operation or maintenance of any nuclear
 * facility.
 *
 * Sun gratefully acknowledges that this software was originally authored
 * and developed by Kenneth Bradley Russell and Christopher John Kline.
 */

package com.jogamp.gluegen;

/** Utility class for handling Opaque directives for JavaEmitter. */

public class TypeInfo {
  private final String   name;
  private final int      pointerDepth;
  private final JavaType javaType;
  private TypeInfo next;

  public TypeInfo(final String name, final int pointerDepth, final JavaType javaType) {
    this.name = name;
    this.pointerDepth = pointerDepth;
    this.javaType = javaType;
  }

  public String   name()                 { return name; }
  public int      pointerDepth()         { return pointerDepth; }
  public JavaType javaType()             { return javaType; }
  public void     setNext(final TypeInfo info) { this.next = info; }
  public TypeInfo next()                 { return next; }

  @Override
  public String toString() {
    final StringBuilder buf = new StringBuilder("TypeInfo: ");
    buf.append(name);
    buf.append(" pointerDepth ");
    buf.append(pointerDepth);
    buf.append(" JavaType " + javaType.getDebugString());
    return buf.toString();
  }
}
